@@ -565,11 +565,16 @@ class EthernetInterface(BaseInterface):
                True if the operation succeeds otherwise False is returned
         """
         commands = ['interface %s' % name]
-        commands.append(self.command_builder('vrf forwarding', vrf,
-                                             default=default, disable=disable))
+        if self.version_number >= '4.23':
+            commands.append(self.command_builder('vrf', vrf,
+                                                 default=default,
+                                                 disable=disable))
+        else:
+            commands.append(self.command_builder('vrf forwarding', vrf,
+                                                 default=default,
+                                                 disable=disable))
         return self.configure(commands)
 
-
 class PortchannelInterface(BaseInterface):
 
     def __str__(self):
@@ -826,7 +831,7 @@ class VxlanInterface(BaseInterface):
             * udp_port (int): The vxlan udp-port value
             * vlans (dict): The vlan to vni mappings
             * flood_list (list): The list of global VTEP flood list
-            * multicast_decap (bool): If the mutlicast decap
+            * multicast_decap (bool): If the multicast decap
                                       feature is configured
 
         Args:
@@ -879,7 +884,7 @@ class VxlanInterface(BaseInterface):
         return dict(multicast_group=value)
 
     def _parse_multicast_decap(self, config):
-        value = 'vxlan mutlicast-group decap' in config
+        value = 'vxlan multicast-group decap' in config
         return dict(multicast_decap=bool(value))
 
     def _parse_udp_port(self, config):
@@ -1059,7 +1064,7 @@ class VxlanInterface(BaseInterface):
             True if the command completes successfully
 
         """
-        cmd = 'vxlan vlan %s vni %s' % (vid, vni)
+        cmd = 'vxlan vlan add %s vni %s' % (vid, vni)
         return self.configure_interface(name, cmd)
 
     def remove_vlan(self, name, vid):
@@ -1075,7 +1080,7 @@ class VxlanInterface(BaseInterface):
             True if the command completes successfully
 
         """
-        return self.configure_interface(name, 'no vxlan vlan %s vni' % vid)
+        return self.configure_interface(name, 'vxlan vlan remove %s vni' % vid)
 
 
 INTERFACE_CLASS_MAP = {
