@@ -48,7 +48,7 @@ Example:
 
     >>> import pyeapi
     >>> conn = pyeapi.connect(host='10.1.1.1', transport='http')
-    >>> conn.execute(['show verson'])
+    >>> conn.execute(['show version'])
     {u'jsonrpc': u'2.0', u'result': [{u'memTotal': 2028008, u'version':
     u'4.14.5F', u'internalVersion': u'4.14.5F-2209869.4145F', u'serialNumber':
     u'', u'systemMacAddress': u'00:0c:29:f5:d2:7d', u'bootupTimestamp':
@@ -90,9 +90,8 @@ configuration file.  The configuration file is an INI style file that
 contains the settings for nodes used by the connect_to function.
 
 """
+from uuid import uuid4
 import os
-import sys
-import logging
 import re
 
 try:
@@ -108,6 +107,7 @@ except ImportError:
 from pyeapi.utils import load_module, make_iterable, debug
 
 from pyeapi.eapilib import HttpEapiConnection, HttpsEapiConnection
+from pyeapi.eapilib import HttpsEapiCertConnection
 from pyeapi.eapilib import SocketEapiConnection, HttpLocalEapiConnection
 from pyeapi.eapilib import CommandError
 
@@ -117,7 +117,8 @@ TRANSPORTS = {
     'socket': SocketEapiConnection,
     'http_local': HttpLocalEapiConnection,
     'http': HttpEapiConnection,
-    'https': HttpsEapiConnection
+    'https': HttpsEapiConnection,
+    'https_certs': HttpsEapiCertConnection
 }
 
 DEFAULT_TRANSPORT = 'https'
@@ -312,8 +313,11 @@ class Config(SafeConfigParser):
 
 # TODO: This is a global variable (in the module) - to review the impact on
 # having a shared state for the config file.
+
+
 config = Config()
 
+
 def load_config(filename):
     """Function method that loads a conf file
 
@@ -326,6 +330,7 @@ def load_config(filename):
     """
     return config.load(filename)
 
+
 def config_for(name):
     """ Function to get settings for named config
 
@@ -343,6 +348,7 @@ def config_for(name):
     """
     return config.get_connection(name)
 
+
 def hosts_for_tag(tag):
     """ Returns the hosts assocated with the specified tag
 
@@ -360,6 +366,7 @@ def hosts_for_tag(tag):
     """
     return config.tags.get(tag)
 
+
 def make_connection(transport, **kwargs):
     """ Creates a connection instance based on the transport
 
@@ -383,8 +390,10 @@ def make_connection(transport, **kwargs):
     klass = TRANSPORTS[transport]
     return klass(**kwargs)
 
+
 def connect(transport=None, host='localhost', username='admin',
-            password='', port=None, timeout=60, return_node=False, **kwargs):
+            password='', port=None, key_file=None, cert_file=None,
+            ca_file=None, timeout=60, return_node=False, **kwargs):
     """ Creates a connection using the supplied settings
 
     This function will create a connection to an Arista EOS node using
@@ -403,6 +412,10 @@ def connect(transport=None, host='localhost', username='admin',
         port (int): The TCP port of the endpoint for the eAPI connection.  If
             this keyword is not specified, the default value is automatically
             determined by the transport type. (http=80, https=443)
+        key_file (str): Path to private key file for ssl validation
+        cert_file (str): Path to PEM formatted cert file for ssl validation
+        ca_file (str): Path to CA PEM formatted cert file for ssl validation
+        timeout (int): timeout
         return_node (bool): Returns a Node object if True, otherwise
             returns an EapiConnection object.
 
@@ -413,10 +426,13 @@ def connect(transport=None, host='localhost', username='admin',
     """
     transport = transport or DEFAULT_TRANSPORT
     connection = make_connection(transport, host=host, username=username,
-                                 password=password, port=port, timeout=timeout)
+                                 password=password, key_file=key_file,
+                                 cert_file=cert_file, ca_file=ca_file,
+                                 port=port, timeout=timeout)
     if return_node:
         return Node(connection, transport=transport, host=host,
-                    username=username, password=password, port=port, **kwargs)
+                    username=username, password=password, key_file=key_file,
+                    cert_file=cert_file, ca_file=ca_file, port=port, **kwargs)
     return connection
 
 
@@ -453,6 +469,10 @@ class Node(object):
         self._connection = connection
         self._running_config = None
         self._startup_config = None
+        self._version = None
+        self._version_number = None
+        self._model = None
+        self._session_name = None
 
         self._enablepwd = kwargs.get('enablepwd')
         self.autorefresh = kwargs.get('autorefresh', True)
@@ -484,6 +504,46 @@ class Node(object):
                                                as_string=True)
         return self._startup_config
 
+    @property
+    def version(self):
+        if self._version:
+            return self._version
+        self._get_version_properties()
+        return self._version
+
+    @property
+    def version_number(self):
+        if self._version_number:
+            return self._version_number
+        self._get_version_properties()
+        return self._version_number
+
+    @property
+    def model(self):
+        if self._model:
+            return self._model
+        self._get_version_properties()
+        return self._model
+
+    def _get_version_properties(self):
+        """Parses version and model information out of 'show version' output
+        and uses the output to populate class properties.
+        """
+        # Parse out version info
+        output = self.enable('show version')
+        self._version = str(output[0]['result']['version'])
+        match = re.match(r'[\d.\d]+', str(output[0]['result']['version']))
+        if match:
+            self._version_number = str(match.group(0))
+        else:
+            self._version_number = str(output[0]['result']['version'])
+        # Parse out model number
+        match = re.search(r'\d\d\d\d', str(output[0]['result']['modelName']))
+        if match:
+            self._model = str(match.group(0))
+        else:
+            self._model = str(output[0]['result']['modelName'])
+
     def enable_authentication(self, password):
         """Configures the enable mode authentication password
 
@@ -498,7 +558,7 @@ class Node(object):
         """
         self._enablepwd = str(password).strip()
 
-    def config(self, commands):
+    def config(self, commands, **kwargs):
         """Configures the node with the specified commands
 
         This method is used to send configuration commands to the node.  It
@@ -511,18 +571,29 @@ class Node(object):
                 a list.
                 The list of commands will also be prepended with the
                 necessary commands to put the session in config mode.
+            **kwargs: Additional keyword arguments for expanded eAPI
+                functionality. Only supported eAPI params are used in building
+                the request
 
         Returns:
             The config method will return a list of dictionaries with the
                 output from each command.  The function will strip the
                 response from any commands it prepends.
         """
+        if self._session_name:  # If in a config session
+            return self._configure_session(commands, **kwargs)
+
+        return self._configure_terminal(commands, **kwargs)
+
+    def _configure_terminal(self, commands, **kwargs):
+        """Configures the node with the specified commands with leading "configure terminal"
+        """
         commands = make_iterable(commands)
         commands = list(commands)
 
         # push the configure command onto the command stack
         commands.insert(0, 'configure terminal')
-        response = self.run_commands(commands)
+        response = self.run_commands(commands, **kwargs)
 
         if self.autorefresh:
             self.refresh()
@@ -532,6 +603,24 @@ class Node(object):
 
         return response
 
+    def _configure_session(self, commands, **kwargs):
+        """Configures the node with the specified commands with leading "configure session <session name>"
+        """
+        if not self._session_name:
+            raise CommandError('Not currently in a session')
+
+        commands = make_iterable(commands)
+        commands = list(commands)
+
+        # push the configure command onto the command stack
+        commands.insert(0, 'configure session %s' % self._session_name)
+        response = self.run_commands(commands, **kwargs)
+
+        # pop the configure command output off the stack
+        response.pop(0)
+
+        return response
+
     def section(self, regex, config='running_config'):
         """Returns a section of the config
 
@@ -560,8 +649,8 @@ class Node(object):
         block_end = line_end + block_end
         return config[block_start:block_end]
 
-    def enable(self, commands, encoding='json', strict=False, 
-              send_enable=True):
+    def enable(self, commands, encoding='json', strict=False,
+               send_enable=True, **kwargs):
         """Sends the array of commands to the node in enable mode
 
         This method will send the commands to the node and evaluate
@@ -579,6 +668,9 @@ class Node(object):
                 command with text encoding if JSON encoding fails
             send_enable (bool): If True the enable command will be
                                prepended to the command list automatically.
+            **kwargs: Additional keyword arguments for expanded eAPI
+                functionality. Only supported eAPI params are used in building
+                the request
 
         Returns:
             A dict object that includes the response for each command along
@@ -607,7 +699,8 @@ class Node(object):
         # there in error and both are now present to avoid breaking
         # existing scripts. 'response' will be removed in a future release.
         if strict:
-            responses = self.run_commands(commands, encoding, send_enable)
+            responses = self.run_commands(commands, encoding, send_enable,
+                                          **kwargs)
             for index, response in enumerate(responses):
                 results.append(dict(command=commands[index],
                                     result=response,
@@ -616,13 +709,15 @@ class Node(object):
         else:
             for command in commands:
                 try:
-                    resp = self.run_commands(command, encoding, send_enable)
+                    resp = self.run_commands(command, encoding, send_enable,
+                                             **kwargs)
                     results.append(dict(command=command,
                                         result=resp[0],
                                         encoding=encoding))
                 except CommandError as exc:
                     if exc.error_code == 1003:
-                        resp = self.run_commands(command, 'text', send_enable)
+                        resp = self.run_commands(command, 'text', send_enable,
+                                                 **kwargs)
                         results.append(dict(command=command,
                                             result=resp[0],
                                             encoding='text'))
@@ -630,12 +725,13 @@ class Node(object):
                         raise
         return results
 
-    def run_commands(self, commands, encoding='json', send_enable=True):
+    def run_commands(self, commands, encoding='json', send_enable=True,
+                     **kwargs):
         """Sends the commands over the transport to the device
 
         This method sends the commands to the device using the nodes
         transport.  This is a lower layer function that shouldn't normally
-        need to be used, prefering instead to use config() or enable().
+        need to be used, preferring instead to use config() or enable().
 
         Args:
             commands (list): The ordered list of commands to send to the
@@ -644,6 +740,9 @@ class Node(object):
                 excpected response.
             send_enable (bool): If True the enable command will be
                                prepended to the command list automatically.
+            **kwargs: Additional keyword arguments for expanded eAPI
+                functionality. Only supported eAPI params are used in building
+                the request
 
         Returns:
             This method will return the raw response from the connection
@@ -669,7 +768,7 @@ class Node(object):
             else:
                 commands.insert(0, 'enable')
 
-        response = self._connection.execute(commands, encoding)
+        response = self._connection.execute(commands, encoding, **kwargs)
 
         # pop enable command from the response only if we sent enable
         if send_enable:
@@ -753,6 +852,41 @@ class Node(object):
         self._running_config = None
         self._startup_config = None
 
+    def configure_session(self):
+        """Enter a config session
+        """
+        self._session_name = self._session_name or uuid4()
+
+    def diff(self):
+        """Returns session-config diffs in text encoding
+
+        Note: "show session-config diffs" doesn't support json encoding
+        """
+        response = self._configure_session(['show session-config diffs'], encoding='text')
+
+        return response[0]['output']
+
+    def commit(self):
+        """Commits the current config session
+        """
+        return self._configure_and_exit_session(['commit'])
+
+    def abort(self):
+        """Aborts the current config session
+        """
+        return self._configure_session(['abort'])
+
+    def _configure_and_exit_session(self, commands, **kwargs):
+        response = self._configure_session(commands, **kwargs)
+
+        if self.autorefresh:
+            self.refresh()
+
+        # Exit the current config session
+        self._session_name = None
+
+        return response
+
 
 def connect_to(name):
     """Creates a node instance based on an entry from the config
