@@ -501,12 +501,12 @@ class TestApiVxlanInterface(EapiConfigUnitTest):
         self.eapi_positive_config_test(func, cmds)
 
     def test_update_vlan(self):
-        cmds = ['interface Vxlan1', 'vxlan vlan 10 vni 10']
+        cmds = ['interface Vxlan1', 'vxlan vlan add 10 vni 10']
         func = function('update_vlan', 'Vxlan1', 10, 10)
         self.eapi_positive_config_test(func, cmds)
 
     def test_remove_vlan(self):
-        cmds = ['interface Vxlan1', 'no vxlan vlan 10 vni']
+        cmds = ['interface Vxlan1', 'vxlan vlan remove 10 vni']
         func = function('remove_vlan', 'Vxlan1', 10)
         self.eapi_positive_config_test(func, cmds)
 
